test

# configurator report¶

This notebook contains the automatic `configurator` report based on preliminary PE results.

Data provenance

PE summary file | /Users/hestelles/Downloads/IGWN-GWTC2p1-v2-GW190521_030229_PEDataRelease_mixed_cosmo.h5
Data set | C01:IMRPhenomXPHM
md5sum of file | 1deb959cc9a8e0ac46e349e9a69446ae
git revision of data | N/A__DIRTY

Settings

$f_{\rm low}$ | 20.0 Hz
$f_{\rm ref}$ | 20.0 Hz
Max $\ell$ for Nyquist check | 3
Tolerance for railing | 2.0
nbins for railing | 50

## Automatically generated analysis¶

- **The median $\chi_{

m eff}<0.1$! **

    2023-04-12  09:53:46 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:53:46 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:53:46 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default

## Summary of posterior sample parameters¶

| $\mathcal{M}$ | $M_{\rm total}$ | $q$ | $d_{L}$ | $\chi_{1z}$ | $\chi_{2z}$
--- | --- | --- | --- | --- | --- | ---
count | 24545.000000 | 24545.000000 | 24545.000000 | 24545.000000 | 24545.000000 | 24545.000000
mean | 101.022441 | 246.369517 | 0.596005 | 3511.106282 | -0.241198 | 0.057765
std | 17.940052 | 30.514662 | 0.189619 | 1486.125523 | 0.412610 | 0.330695
min | 42.062421 | 154.336022 | 0.093182 | 532.472390 | -0.986375 | -0.967804
25% | 90.476364 | 224.100686 | 0.483799 | 2233.912381 | -0.597967 | -0.125304
50% | 101.023348 | 243.261116 | 0.587144 | 3310.919418 | -0.256579 | 0.032207
75% | 112.044434 | 263.451499 | 0.723183 | 4631.872774 | 0.041395 | 0.265922
max | 165.000822 | 382.238356 | 1.000000 | 9332.801421 | 0.981063 | 0.989237

## Posterior railing visual check¶

Automatic checks on railing. Note that the recommendations are ad-hoc and may not result in posteriors not being cut off.

|  | Recommendation
--- | --- | ---
chirp_mass | PASSED |
distance | PASSED |
mass_ratio | PASSED |

Plot of selected posterior parameters. All masses are in the detector frame. The red dashed lines show the proposed $\mathcal{M}$ bounds,[33.6499,198.001]

## MECO frequency check¶

The reference frequency is shown as a dashed green vertical line. If the reference frequency has been modified by the MECO test, the input value appears in red and the new value in green.

|  | Recommendation
--- | --- | ---
f_ref | FAILED. f_ref has been overwritten to a safe value. |

## Recommended settings¶

seglen | 4.0 sec.
srate | 512
$f_{\rm start}$ | 4.0996 Hz
$f_{\rm ref}$ | 4.3116 Hz
$\mathcal{M}$ bounds | [33.6499,198.001]

## Extra information¶

Date | 2023-04-12 09:53:42.469677
Script revision | ad853bac7cca41f13b704b059414ff09d8157603__DIRTY
Complete arguments | Namespace(output_dir='examples/test_GW190521', HM=True, q_min=None, ell_max=3, tolerance=2.0, nbins=50, flow=20.0, f_ref=20.0, bounds_tol=0.2, json_file='test.json', report_file='test.pdf', override_safeties=False, debug=False, include_dL_recommendations=False)